@@ -1,6 +1,6 @@
 package Bio::Palantir::Roles::Domainable;
 # ABSTRACT: Domainable Moose role for Domain and DomainPlus objects
-$Bio::Palantir::Roles::Domainable::VERSION = '0.200700';
+$Bio::Palantir::Roles::Domainable::VERSION = '0.201670';
 use Moose::Role;
 
 use autodie;
@@ -25,7 +25,7 @@ sub symbol {
     return 'na' unless $name;
 
     my $symbol = 
-        $name =~ m/^ACL$ | ^CAL$/xms
+        $name =~ m/^ACL$ | ^CAL/xms
         ? 'CAL'
         : $name =~ m/^A$ | AMP-binding/xms 
         ? 'A' 
@@ -144,7 +144,7 @@ Bio::Palantir::Roles::Domainable - Domainable Moose role for Domain and DomainPl
 
 =head1 VERSION
 
-version 0.200700
+version 0.201670
 
 =head1 SYNOPSIS
 
